@@ -739,6 +739,9 @@ class OptionalsParser(argparse.ArgumentParser):
                 if option_tuple is None:
                     pattern = "A"
                 else:
+                    if len(option_tuple) == 1:
+                        # https://github.com/python/cpython/commit/cbea45ad74779c0ffe760bab7f9d5ce149302495
+                        option_tuple = option_tuple[0]
                     option_string_indices[i] = option_tuple
                     pattern = "O"
                 arg_string_pattern_parts.append(pattern)
@@ -1244,7 +1247,15 @@ class ArgumentParser(OptionalsParser, CsvActionsParser):
                 namespace, args = functor(parser, namespace, args)
 
             # parse the arguments and exit if there are any errors
-            namespace, args = self._parse_known_args(args, namespace)
+            # Python 3.12.8 introduced obligatory intermixed arg.  The same
+            # commit adds _parse_known_args2 function, so use that to determine
+            # if we need to pass that.
+            if hasattr(self, "_parse_known_args2"):
+                namespace, args = self._parse_known_args(
+                    args, namespace, intermixed=False
+                )
+            else:
+                namespace, args = self._parse_known_args(args, namespace)
             if hasattr(namespace, _UNRECOGNIZED_ARGS_ATTR):
                 args.extend(getattr(namespace, _UNRECOGNIZED_ARGS_ATTR))
                 delattr(namespace, _UNRECOGNIZED_ARGS_ATTR)
